@@ -4,11 +4,10 @@ from raincloudy.const import (
     HOME_ENDPOINT, MANUAL_OP_DATA, MANUAL_WATERING_ALLOWED,
     MAX_RAIN_DELAY_DAYS, MAX_WATERING_MINUTES)
 from raincloudy.helpers import (
-    find_controller_or_faucet_name,
-    find_program_status, find_zone_name)
+    find_controller_or_faucet_name, find_zone_name)
 
 
-class RainCloudyFaucetCore(object):
+class RainCloudyFaucetCore():
     """RainCloudyFaucetCore object."""
 
     def __init__(self, parent, controller, faucet_id):
@@ -199,7 +198,7 @@ class RainCloudyFaucetZone(RainCloudyFaucetCore):
         """Set a new zone name to faucet."""
         self._set_zone_name(self.id, value)
 
-    def _set_watering_time(self, zoneid, value):
+    def _set_manual_watering_time(self, zoneid, value):
         """Private method to set watering_time per zone."""
         if value not in MANUAL_WATERING_ALLOWED:
             raise ValueError(
@@ -222,18 +221,26 @@ class RainCloudyFaucetZone(RainCloudyFaucetCore):
     @property
     def watering_time(self):
         """Return watering_time from zone."""
-        # zone starts with index 0
-        index = self.id - 1
-        return self._attributes['rain_delay_mode'][index]['auto_watering_time']
+        auto_watering_time = self.lookup_attr('auto_watering_time')
 
-    @watering_time.setter
-    def watering_time(self, value):
-        """Manually turn on water for X minutes."""
-        return self._set_watering_time(self.id, value)
+        manual_watering_time = self.lookup_attr('manual_watering_time')
+
+        if auto_watering_time > manual_watering_time:
+            watering_time = auto_watering_time
+        else:
+            watering_time = manual_watering_time
+
+        return watering_time
 
     @property
-    def droplet(self):
-        return None
+    def manual_watering(self):
+        """Return zone manual_mode_on"""
+        return self.lookup_attr('manual_mode_on')
+
+    @manual_watering.setter
+    def manual_watering(self, value):
+        """Manually turn on water for X minutes."""
+        return self._set_manual_watering_time(self.id, value)
 
     def _set_rain_delay(self, zoneid, value):
         """Generic method to set auto_watering program."""
@@ -242,7 +249,7 @@ class RainCloudyFaucetZone(RainCloudyFaucetCore):
 
         if isinstance(value, int):
             if value > MAX_RAIN_DELAY_DAYS or value < 0:
-                return None
+                value = None
             elif value == 0:
                 value = 'off'
             elif value == 1:
@@ -251,7 +258,10 @@ class RainCloudyFaucetZone(RainCloudyFaucetCore):
                 value = str(value) + 'days'
         elif isinstance(value, str):
             if value.lower() != 'off':
-                return None
+                value = None
+
+        if value is None:
+            return None
 
         ddata = self.preupdate()
         attr = 'zone{}_rain_delay_select'.format(zoneid)
@@ -262,8 +272,7 @@ class RainCloudyFaucetZone(RainCloudyFaucetCore):
     @property
     def rain_delay(self):
         """Return the rain delay day from zone."""
-        index = self.id - 1
-        return self._attributes['rain_delay_mode'][index]['rain_delay_mode']
+        return self.lookup_attr('rain_delay_mode')
 
     @rain_delay.setter
     def rain_delay(self, value):
@@ -273,8 +282,7 @@ class RainCloudyFaucetZone(RainCloudyFaucetCore):
     @property
     def next_cycle(self):
         """Return the time scheduled for next watering from zone."""
-        index = self.id - 1
-        return self._attributes['rain_delay_mode'][index]['next_water_cycle']
+        return self.lookup_attr('next_water_cycle')
 
     def _set_auto_watering(self, zoneid, value):
         """Private method to set auto_watering program."""
@@ -296,8 +304,7 @@ class RainCloudyFaucetZone(RainCloudyFaucetCore):
     @property
     def auto_watering(self):
         """Return if zone is configured to automatic watering."""
-        value = "zone{}".format(self.id)
-        return find_program_status(self._parent.html['home'], value)
+        return self.lookup_attr('program_mode_on')
 
     @auto_watering.setter
     def auto_watering(self, value):
@@ -309,13 +316,17 @@ class RainCloudyFaucetZone(RainCloudyFaucetCore):
         """Return boolean if zone is watering."""
         return bool(self.watering_time > 0)
 
+    def lookup_attr(self, attr):
+        """Returns rain_delay_mode attributes by zone index"""
+        return self._attributes['rain_delay_mode'][int(self.id) - 1][attr]
+
     def _to_dict(self):
         """Method to build zone dict."""
         return {
             'auto_watering':
                 getattr(self, "auto_watering"),
-            'droplet':
-                getattr(self, "droplet"),
+            'manual_watering':
+                getattr(self, "manual_watering"),
             'is_watering':
                 getattr(self, "is_watering"),
             'name':
