@@ -9,7 +9,8 @@ def generate_soup_html(data):
     try:
         return BeautifulSoup(data, 'html.parser')
     except:
-        raise
+        raise TypeError(
+            'Invalid data passed to BeautifulSoup')
 
 
 def serial_finder(data):
@@ -33,20 +34,20 @@ def serial_finder(data):
 
         # The setup page contains a select box for each controller and each
         # faucet
-        controllersElement = data.find_all('select',
-                                           {'id': 'id_select_controller2'})
+        controllers_element = data.find_all('select',
+                                            {'id': 'id_select_controller2'})
 
-        faucetsElement = data.find_all('select',
-                                       {'id': 'id_select_faucet2'})
+        faucets_element = data.find_all('select',
+                                        {'id': 'id_select_faucet2'})
 
-        controllerSerial = controllersElement[0].text.split('-')[1].strip()
-        faucetSerial = faucetsElement[0].text.split('-')[1].strip()
+        controller_serial = controllers_element[0].text.split('-')[1].strip()
+        faucet_serial = faucets_element[0].text.split('-')[1].strip()
 
         # currently only one faucet is supported on the code
         # we have plans to support it in the future
         parsed_dict = {}
-        parsed_dict['controller_serial'] = controllerSerial
-        parsed_dict['faucet_serial'] = [faucetSerial]
+        parsed_dict['controller_serial'] = controller_serial
+        parsed_dict['faucet_serial'] = [faucet_serial]
         return parsed_dict
 
     except (AttributeError, IndexError, ValueError):
@@ -54,42 +55,6 @@ def serial_finder(data):
             'Could not find any valid controller or faucet')
 
 
-def find_program_status(data, zone):
-    """
-    Find on the HTML document if zoneX has the configuration
-    of the auto-schedule/program (auto_watering) enabled.
-
-    # expected result if enabled
-    #<input checked="checked" class="switch" id="id_zone2_program_toggle" \
-        name="zone2_program_toggle" onchange="submit()" type="checkbox"/>
-
-    # expected result if disabled
-    #<input class="switch" id="id_zone1_program_toggle" \
-        name="zone1_program_toggle" onchange="submit()" type="checkbox"/>
-
-    :param data: BeautifulSoup object
-    :param zone: zone name from class='switch'
-    :return: boolean if zone has program enabled
-    :rtype: boolean
-    :raises TypeError: if data is not a BeautifulSoup object
-    :raises IndexError: if object not found
-    """
-    if not isinstance(data, BeautifulSoup):
-        raise TypeError("Function requires BeautilSoup HTML element.")
-
-    try:
-        child = data.find_all('input', {'class': 'switch'})
-        zone_id = 'id_{0}_program_toggle'.format(zone)
-        for member in child:
-            if member.get('type') == 'checkbox' and \
-               member.get('id') == zone_id:
-                return bool(member.has_attr('checked'))
-        raise IndexError
-    except (AttributeError, IndexError, ValueError):
-        raise RainCloudyException(
-            'Could not find any valid controller or faucet')
-
-
 def find_controller_or_faucet_name(data, p_type):
     """
     Find on the HTML document the controller name.
@@ -112,7 +77,7 @@ def find_controller_or_faucet_name(data, p_type):
     if not isinstance(data, BeautifulSoup):
         raise TypeError("Function requires BeautilSoup HTML element.")
 
-    if not (p_type == 'controller' or p_type == 'faucet'):
+    if p_type not in ('controller', 'faucet'):
         raise TypeError("Function p_type must be controller or faucet")
 
     try:
